*Youth Unemployment Dynamics
*YUD durations of unemployment

*Original: May 8, 2015
* Updated 2023.07.19
*v17

*CK

*Running for 2014, 2016, 2018

*Use synthetic panels for the preceding 10 years created in YUD annualized

/*
Creating unemployment spells

Using entrants into the state of unemployment for the preceding decade

Estimating descriptives as KM 

Estimating discrete time hazard model (logit)

*/

log using "Logs/duration log $S_DATE.log", replace


************************
*Spells of U
*************************

use "Eat/E J T OEU indiv.dta", clear

merge m:1 indid using "LMPS data/Integrated LMPs v4.0.dta"

drop if _merge==2

drop _merge

keep if U==1

****Defining a spell
isid indid year
sort indid year

* spell = number of unemp spells, 
* seq = length of unemp spell
* end = 1 in year in which unemp spell ends

spell, f(_n==1 | (year[_n]-year[_n-1]>1)) by(indid) ///
seq(seq) spell(spell) end(end)

***Drop right censored years

drop if year==2017 & round==1
drop if year==2015 & round==2
drop if year==2013 & round==3

gen LC=0
replace LC=1 if year==2008 & round==1
replace LC=1 if year==2006 & round==2
replace LC=1 if year==2004 & round==3

egen unemp_LC=max(LC), by(indid)

gen LCspell=.
replace LCspell=spell if unemp_LC==0
replace LCspell=spell-1 if unemp_LC==1


*Does individual have an NLC?

egen LConly=max(LCspell), by(indid)
* LCOnly2 is an indicator for only having a left-censored spell
gen LConly2=1 if LConly==0
replace LConly2=0 if LConly!=0

drop LConly
rename LConly2 LConly

tabu spell round
tabu seq round
tabu end round
tabu LC round
tabu LCspell round


tabu LConly round

*How many individuals have only LC spells?
tabu LConly round if LCspell==0 & seq==1

*How many years not in LC spell
tabu LConly round if LCspell!=0

*Spells distribution over censoring
tabu LCspell round if seq==1

*Number of spells
tabu LCspell round if seq==1 & LCspell!=0

save "Eat/U indiv.dta", replace


*************
*K-M graphs
*************

*Spell identifier

gen s_spell=string(LCspell)
gen sp_indid=indid+s_spell
duplicates report sp_indid seq

*Age at start of unemployment spell must be used, can't use a TVC with K-M

egen st_year_ageg=min(year_ageg), by(indid LCspell)

tabu st_year_ageg
tabu st_year_ageg year_ageg


drop year_ageg

rename st_year_ageg year_ageg


stset seq if LCspell>=1 [pw=expan], failure(end==1) id(sp_indid)

sts list, by(sex round)
stsum, by(sex round)

save "Eat/E J T U indiv.dta", replace

preserve

expand 2

bysort indid year: gen tot=_n-1
replace year_ageg=4 if tot==1

drop tot

expand 2

bysort indid year year_ageg: gen tot=_n-1
replace sex=3 if tot==1

stsum, by(sex round year_ageg)

*Figure 7: K-M

foreach num of numlist 1/3 {
foreach num2 of numlist 1/3 {

sts graph if sex==`num' & round==`num2', xtitle("") ytitle("") ///
by(year_ageg) plot1opts(lpatt(dash) lcolor(gs10) lwidth(thick)) ///
plot2opts(lpatt(vshortdash) lcolor(gs7) lwidth(thick)) ///
plot3opts(lpatt("l") lcolor(gs0) lwidth(thick)) ///
xlabel(, labsize(3)) ylabel(, labsize(3)) ///
legend(order(1 "15-29" 2 "30-64" 3 "Total")) ///
title("") plotregion(margin(zero))

graph save "Graphs and Tables/KM_sex`num'_round`num2'.gph", replace
graph export "Graphs and Tables/KM_sex`num'_round`num2'.tif", replace width(500) 

}
}

*One graph
grc1leg  "Graphs and Tables/KM_sex1_round1.gph" ///
 "Graphs and Tables/KM_sex2_round1.gph" ///
 "Graphs and Tables/KM_sex3_round1.gph" ///
 "Graphs and Tables/KM_sex1_round2.gph" ///
 "Graphs and Tables/KM_sex2_round2.gph" ///
 "Graphs and Tables/KM_sex3_round2.gph" ///
 "Graphs and Tables/KM_sex1_round3.gph" ///
 "Graphs and Tables/KM_sex2_round3.gph" ///
 "Graphs and Tables/KM_sex3_round3.gph", ///
 ysize(20) xsize(20) cols(3)  ///
 imargin(tiny) title("     Male                                   Female                                   Total", size(3)) ///
 l1title("    Tunisia                          Jordan                           Egypt", size(3)) ///
 xcommon ycommon
 
graph display, xsize(20) ysize(20)

graph save "Graphs and Tables/KMsex_combo.gph", replace
graph export "Graphs and Tables/KMsex_combo.tif", replace width(1500) 
  
restore


*******************************************************************************
*Discrete time hazard models
*******************************************************************************

use "Eat/E J T U indiv.dta", clear

merge m:1 indid using "LMPS data/Integrated LMPs v4.0.dta"

drop if _merge==2


*Non-LC only

keep if LCspell>=1 

*ID is person-spell

duplicates report sp_indid seq

*************
***Covariates
************* 

gen owneduc=1 if educ1d<=3
replace owneduc=2 if educ1d==4
replace owneduc=3 if educ1d>=5 & educ1d<.
label define Lowneduc 1 "Low" 2 "Intermediate" 3 "High", modify
label val owneduc Lowneduc

* Father and Mother at least basic to be high SES
gen highSES=(fteducst>=3  & mteducst>=3) if fteducst<. & mteducst<.


gen educSES=owneduc
replace educSES=4 if owneduc==3 & highSES==1
label define LeducSES 1 "Low" 2 "Intermediate" 3 "High Ed.-low SES" 4 "High Ed.-high SES", modify
label val educSES LeducSES


gen rural=1 if urban==2
replace rural=0 if urban==1

egen s_year=min(year), by(sp_indid)

gen syr_group=1 if s_year>=2004 & s_year<=2007
replace syr_group=2 if s_year>=2008 & s_year<=2010
replace syr_group=3 if s_year>=2011 & s_year<=2013
replace syr_group=4 if s_year>=2014 & s_year<=2016

la def Lsyr_group 1 "2004-2007" 2 "2008-2010" ///
3 "2011-2013" 4 "2014-2016" 

la val syr_group Lsyr_group

*Combining spell of 6+ years
gen tseq=seq
recode tseq 7/10=6


*************
***Models
************* 

destring sp_indid, replace
sort sp_indid seq

set seed 987234732

***Model testing for differences by country and sex
logit end i.round##i.sex##i.year_ageg i.round##i.sex##b4.educSES i.round##i.sex##i.rural i.round##i.sex##i.syr_group i.round##i.sex##i.tseq i.round##i.sex##i.evrmar [pw=expan_indiv]

margins 1.round#1.sex 1.round#2.sex 2.round#1.sex 2.round#2.sex 3.round#1.sex 3.round#2.sex, noestimcheck post

*Test for gender differences in each country
*Egypt
test 1.round#1.sex=1.round#2.sex
*Jordan
test 2.round#1.sex=2.round#2.sex
*Tunisia
test 3.round#1.sex=3.round#2.sex

*Test across countries, within sex
*Egypt v. Jordan, men
test 1.round#1.sex=2.round#1.sex
*Egypt v. Jordan, women
test 1.round#2.sex=2.round#2.sex
*Egypt v. Tunisia, men
test 1.round#1.sex=3.round#1.sex
*Egypt v. Tunisia, women
test 1.round#2.sex=3.round#2.sex
*Tunisia v. Jordan, men
test 3.round#1.sex=2.round#1.sex
*Tuniisa v. Jordan, women
test 3.round#2.sex=2.round#2.sex

***Loop for unemployment exit by country

estimates clear

*Round/country
foreach num of numlist 1/3 {
	*Sex
	foreach num2 of numlist 1/2 {
		
*Check missings		
sum end i.year_ageg i.educSES i.syr_group i.rural i.tseq i.evrmar  if round==`num' & sex==`num2'

*Model 
logit end i.year_ageg b4.educSES i.rural i.syr_group i.evrmar i.tseq [pw=expan_indiv]  if round==`num' & sex==`num2',  or cluster(Fpsu) 

estimates store c_`num'_s_`num2'

*Margins
margins, over(tseq)  predict(pr) saving("Eat/c_`num'_s_`num2'.dta", replace)

	}
}

*Figure 


combomarginsplot "Eat/c_1_s_1.dta" "Eat/c_1_s_2.dta" "Eat/c_2_s_1.dta" "Eat/c_2_s_2.dta" "Eat/c_3_s_1.dta" "Eat/c_3_s_2.dta", xdim(tseq) ///
labels("Egypt Males" "Egypt Females" "Jordan Males" "Jordan Females" "Tunisia Males" "Tunisia Females", size(4)) ///
xtitle("Years since unemp. spell start") ytitle("Proportion exiting unemp. (Hazard)") ///
 legend(rows(3) size(2)) xlabel(1 (1) 6)  title ("") ///
 plot1opt(lcolor(gs0) m(V) mcolor(gs0) lpattern(solid)) ///
 plot2opt(lcolor(gs0) m(X) mcolor(gs0) lpattern(longdash_dot) msize(large) mlwidth(medthick)) ///
 plot3opt(lcolor(gs7) mcolor(gs7) m(Sh) lpattern(shortdash) lwidth(medium )) ///
 plot4opt(lcolor(gs7) mcolor(gs7) m(Th) lpattern(dash_dot)) ///
 plot5opt(lcolor(gs13) mcolor(gs13) m(Dh) lpattern(shortdash_dot)) ///
 plot6opt(lcolor(gs13) mcolor(gs13) m(Oh) lpattern(dash) lwidth(medium)) ///
    ci1opt (color(gs0)) ///
 ci2opt (color(gs0) )  ///
 ci3opt (color(gs7)) ///
 ci4opt (color(gs7) ) /// 
 ci5opt (color(gs13)) ///
 ci6opt (color(gs13) ) ///
 graphregion(color(white))


graph save "Graphs and Tables/hazard.gph", replace
graph export "Graphs and Tables/hazard.tif", replace width(1500) 
 
esttab c_*_s_* using "Graphs and Tables/Unemp_models.csv", cells(b(star fmt(%9.3f)) se(par))  ///     
 order(*year_ageg *educSES *rural 2.syr_group 3.syr_group 4.syr_group *evrmar *tseq) stats(N, fmt(%9.0g))   ///
	legend  mlabel("Egypt Males" "Egypt Females" "Jordan Males" "Jordan Females" "Tunisia Males" "Tunisia Females") ///
	refcat(2.year_ageg "Age group (15-29 omit.)" ///
	2.tseq "Year of unemployment (1 omit.)" 1.educSES "Education and SES (higher ed.- high SES omit.)" 1.rural "Rural (urban omit.)" 1.evrmar "Ever married (not yet omit.)" ///
	2.syr_group "Start year (2004-07 omit. Jordan Tunsia & 2008-2010 omit. Egypt)" , nolabel)       ///
	coeflabels(2.year_ageg "30-64" 1.educSES "Low" 2.educSES "Intermediate" 3.educSES "High ed. - low SES" 1.rural "Rural" 2.syr_group "2008-2010" 3.syr_group "2011-13" 4.syr_group "2014-16" 1.evrmar "Ever married" 2.tseq "2" 3.tseq "3" 4.tseq "4" 5.tseq "5" 6.tseq "6+") ///
	eform replace noomit nobase

log close
